List or Find Products
/product
Request
-
billingAccount.id: string
The ID of the associated billing account.
-
cycleEndDate: string(date-time)
The purchased product cycle end date in ISO-8601 date-time format.
-
cycleStartDate: string(date-time)
The purchased product cycle start date in ISO-8601 date-time format.
-
description: string
The resource's description.
-
fields: string
Specifies the comma-separated properties to include in the response.
-
filter: string
Specifies an advanced filter expression for nested fields, for example JSONPath.Examples
-
isBundle: boolean
Wether the resource is a bundle.
-
limit: integer
Specifies the number of resources to include in the response.
-
name: string
The resource's name.
-
offset: integer
Specifies the index of the first resource to include in the response.
-
productCharacteristic.id: string
The ID of the associated product characteristic.
-
productOffering.id: string
The identifier of the associated product offering.
-
productOffering.name: string
The name of the associated product offering.
-
purchaseEndDate: string(date-time)
The purchased product purchase end date in ISO-8601 date-time format.
-
purchaseStartDate: string(date-time)
The purchased product purchase start date in ISO-8601 date-time format.
-
quantity: integer
The service quantity when creating a purchase product.
-
realizingService.id: string
The ID of the associated realizing service.
-
specialRatingProfile.data.name: string
The special rating profile data attribute name. Append a supported operator suffix to the parameter name when required; an unsuffixed parameter uses equality.Example:
dummy -
specialRatingProfile.data.name.eq: string
Filters products whose special rating profile data name equals the specified value.Example:
dummy -
specialRatingProfile.data.name.like: string
Filters products whose special rating profile data name matches the specified wildcard pattern.Example:
dum% -
specialRatingProfile.data.validFor.endDateTime: string(date-time)
The end of the special rating profile data validity period. Append a supported comparison operator suffix to the parameter name when required; an unsuffixed parameter uses equality.Example:
2031-05-01T00:00:00.00Z -
specialRatingProfile.data.validFor.endDateTime.eq: string(date-time)
Filters products whose special rating profile data end time equals the specified date-time.Example:
2031-05-01T00:00:00.00Z -
specialRatingProfile.data.validFor.endDateTime.gt: string(date-time)
Filters products whose special rating profile data end time is after the specified date-time.Example:
2031-04-30T00:00:00.00Z -
specialRatingProfile.data.validFor.endDateTime.gte: string(date-time)
Filters products whose special rating profile data end time is after or equal to the specified date-time.Example:
2031-05-01T00:00:00.00Z -
specialRatingProfile.data.validFor.endDateTime.lt: string(date-time)
Filters products whose special rating profile data end time is before the specified date-time.Example:
2031-05-02T00:00:00.00Z -
specialRatingProfile.data.validFor.endDateTime.lte: string(date-time)
Filters products whose special rating profile data end time is before or equal to the specified date-time.Example:
2031-05-01T00:00:00.00Z -
specialRatingProfile.data.validFor.startDateTime: string(date-time)
The start of the special rating profile data validity period. Append a supported comparison operator suffix to the parameter name when required; an unsuffixed parameter uses equality.Example:
2031-04-02T18:23:39.00Z -
specialRatingProfile.data.validFor.startDateTime.eq: string(date-time)
Filters products whose special rating profile data start time equals the specified date-time.Example:
2031-04-02T18:23:39.00Z -
specialRatingProfile.data.validFor.startDateTime.gt: string(date-time)
Filters products whose special rating profile data start time is after the specified date-time.Example:
2031-04-01T00:00:00.00Z -
specialRatingProfile.data.validFor.startDateTime.gte: string(date-time)
Filters products whose special rating profile data start time is after or equal to the specified date-time.Example:
2031-04-02T18:23:39.00Z -
specialRatingProfile.data.validFor.startDateTime.lt: string(date-time)
Filters products whose special rating profile data start time is before the specified date-time.Example:
2031-04-03T00:00:00.00Z -
specialRatingProfile.data.validFor.startDateTime.lte: string(date-time)
Filters products whose special rating profile data start time is before or equal to the specified date-time.Example:
2031-04-02T18:23:39.00Z -
specialRatingProfile.data.value: string
The special rating profile data attribute value. Append a supported operator suffix to the parameter name when required; an unsuffixed parameter uses equality.Example:
0449335686849545 -
specialRatingProfile.data.value.eq: string
Filters products whose special rating profile data value equals the specified value.Example:
0449335686849545 -
specialRatingProfile.data.value.like: string
Filters products whose special rating profile data value matches the specified wildcard pattern.Example:
044% -
specialRatingProfile.id: string
The identifier of the special rating profile. Append a supported operator suffix to the parameter name when required; an unsuffixed parameter uses equality.Example:
88-1ZVHQ4-044 -
specialRatingProfile.id.eq: string
Filters products whose special rating profile identifier equals the specified value.Example:
88-1ZVHQ4-044 -
specialRatingProfile.id.like: string
Filters products whose special rating profile identifier matches the specified wildcard pattern.Example:
88-1ZVHQ4-% -
specialRatingProfile.label: string
The special rating profile label. Append a supported operator suffix to the parameter name when required; an unsuffixed parameter uses equality.Example:
Smart Calling up to 5 Numbers -
specialRatingProfile.label.eq: string
Filters products whose special rating profile label equals the specified value.Example:
Smart Calling up to 5 Numbers -
specialRatingProfile.label.like: string
Filters products whose special rating profile label matches the specified wildcard pattern.Example:
Smart% -
specialRatingProfile.name: string
The special rating profile name. Append a supported operator suffix to the parameter name when required; an unsuffixed parameter uses equality.Example:
FRIENDS_FAMILY -
specialRatingProfile.name.eq: string
Filters products whose special rating profile name equals the specified value.Example:
FRIENDS_FAMILY -
specialRatingProfile.name.like: string
Filters products whose special rating profile name matches the specified wildcard pattern.Example:
FRIENDS% -
specialRatingProfile.referenceCount: integer
The special rating profile reference count. Append a supported comparison operator suffix to the parameter name when required; an unsuffixed parameter uses equality.Example:
1 -
specialRatingProfile.referenceCount.eq: integer
Filters products whose special rating profile reference count equals the specified value.Example:
1 -
specialRatingProfile.referenceCount.gt: integer
Filters products whose special rating profile reference count is greater than the specified value.Example:
0 -
specialRatingProfile.referenceCount.gte: integer
Filters products whose special rating profile reference count is greater than or equal to the specified value.Example:
1 -
specialRatingProfile.referenceCount.lt: integer
Filters products whose special rating profile reference count is less than the specified value.Example:
2 -
specialRatingProfile.referenceCount.lte: integer
Filters products whose special rating profile reference count is less than or equal to the specified value.Example:
1 -
specialRatingProfile.status: string
The special rating profile provisioning status. Append a supported operator suffix to the parameter name when required; an unsuffixed parameter uses equality.Allowed Values:
[ "noop", "provisioning", "provisioningFailed", "active", "unprovisioning", "unprovisioningFailed", "unprovisioned", "suspending", "suspendingFailed", "suspended" ]Example:active -
specialRatingProfile.status.eq: string
Filters products whose special rating profile status equals the specified value.Example:
active -
specialRatingProfile.status.gt: string
Filters products whose special rating profile status follows the specified status in mapper enum order.Example:
active -
specialRatingProfile.status.gte: string
Filters products whose special rating profile status follows or equals the specified status in mapper enum order.Example:
active -
specialRatingProfile.status.lt: string
Filters products whose special rating profile status precedes the specified status in mapper enum order.Example:
active -
specialRatingProfile.status.lte: string
Filters products whose special rating profile status precedes or equals the specified status in mapper enum order.Example:
active -
startDate: string(date-time)
The resource start date. The expected ISO-8601 format: 2025-01-02T01:30:00Z.Example:
2018-01-02T01:30:00Z -
status: string
The resource's status.
-
terminationDate: string(date-time)
The resource termination date. The expected ISO-8601 format: 2025-01-02T01:30:00Z.Example:
2025-01-02T01:30:00Z -
usageEndDate: string(date-time)
The purchased product usage end date in ISO-8601 date-time format.
-
usageStartDate: string(date-time)
The purchased product usage start date in ISO-8601 date-time format.
There's no request body for this operation.
Back to TopResponse
200 Response
-
X-Result-Count:
The actual number of items returned in the response body.
-
X-Total-Count:
The total number of items that match the criteria.
-
object
allOf
Entity
Represents a base entity schema for TM Forum Open APIs.
-
object
Product-allOf[1]
A product offering procured by a customer or any other party playing a party role. The product is realized as one or more services or resources.
-
allOf
Product
-
object
ProductOracle-allOf[1]
A product offering procured by a customer or other interested party playing a party role. A product is realized as one or more service and/or resources.
object-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Addressable
Defines a base schema for addressable entities.
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
href: string
The hyperlink reference.
-
id: string
The ID.
object-
billingAccount:
Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "BillingAccountRef":"#/components/schemas/BillingAccountRef" } } -
description: string
Describes the product. You can copy it from the product offering description.
-
isBundle: boolean
Indicates whether the product is a ProductBundle (true) or a ProductComponent (false).
-
name: string
The product name; it can match the product offering name.
-
product: array
product
-
productCharacteristic: array
productCharacteristic
-
productOffering:
Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "ProductOfferingRef":"#/components/schemas/ProductOfferingRef" } } -
productPrice: array
productPrice
-
productRelationship: array
productRelationship
-
realizingService: array
realizingService
-
startDate: string
(date-time)
The date the product starts.
-
status: string
Allowed Values:
[ "created", "pendingActive", "cancelled", "active", "pendingTerminate", "terminated", "suspended", "aborted" ]The possible values for a product's status. -
terminationDate: string
(date-time)
The date the product was terminated.
objectDiscriminator Values
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
allOf
EntityRef
-
object
Discriminator: @type-allOf[2]
Refers to the billing account. The billing account describes the bill structure.
array-
Array of:
object Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "Product":"#/components/schemas/Product", "ProductRef":"#/components/schemas/ProductRef", "ProductOracle":"#/components/schemas/ProductOracle" } }The polymorphic attributes (@type, @schemaLocation, and @referredType) apply to the Product entity, not to the ProductRefOrValue class.
objectDiscriminator Values
-
allOf
EntityRef
-
object
Discriminator: @type-allOf[1]
Represents entities that are orderable from the catalog provider. This resource includes pricing information.
array-
Array of:
object Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "ProductPrice":"#/components/schemas/ProductPrice" } }
array-
Array of:
object Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "ProductRelationship":"#/components/schemas/ProductRelationship" } }
array-
Array of:
object Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "ServiceRef":"#/components/schemas/ServiceRef" } }The service reference used by other entities.
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Addressable
Defines a base schema for addressable entities.
-
object
EntityRef-allOf[2]
Represents an entity reference schema for EntityRef classes.
object-
@referredType: string
The actual type of the target instance when needed for disambiguation.
-
href: string
The URI of the referred entity.
-
id(required): string
The identifier of the referred entity.
-
name: string
The referred entity's name.
object-
ratingType: string
Indicates if the account follows a specific payment option such as prepaid or postpaid.
objectDiscriminator Values
-
Product
-
object
ProductRef
A product reference.
-
ProductOracle
object-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
allOf
EntityRef
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Characteristic-allOf[1]
Describes a given characteristic of an object or entity through a name/value pair.
object-
characteristicRelationship: array
characteristicRelationship
-
id: string
The characteristic's ID.
-
name: string
The characteristic's name.
-
valueType: string
The characteristic value's data type.
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
CharacteristicRelationship-allOf[1]
The related characteristic.
object-
id: string
The characteristic's ID.
-
relationshipType: string
The relationship type.
object-
version: string
Version of the product offering
objectDiscriminator Values
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Discriminator: @type-allOf[1]
Describes the price and any discount awarded.
object-
description: string
A description of the product price.
-
name: string
The name of the product price.
-
price:
Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "Price":"#/components/schemas/Price" } } -
priceAlteration: array
priceAlteration
-
priceType: string
Indicates whether the price is for a recurring or a non-recurring charge.
-
productOfferingPrice:
Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "ProductOfferingPriceRef":"#/components/schemas/ProductOfferingPriceRef" } } -
recurringChargePeriod: string
Indicates the period for a recurring charge (for example: month or week).
-
unitOfMeasure: string
Unit of measure if the price depends on it (for example: GB or SMS volume).
objectDiscriminator Values
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Discriminator: @type-allOf[1]
Provides monetary amounts (tax included, duty-free), currency, and percentages to apply to Price and PriceAlteration.
array-
Array of:
object Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "PriceAlteration":"#/components/schemas/PriceAlteration" } }
objectDiscriminator Values
-
allOf
EntityRef
-
object
Discriminator: @type-allOf[1]
An amount, usually monetary, that is asked for or allowed when a ProductOffering is bought, rented, or leased.
object-
dutyFreeAmount: object
Money
Represents a monetary amount.
-
percentage: number
(float)
The percentage to apply to a product offering price alteration.
-
taxIncludedAmount: object
Money
Represents a monetary amount.
-
taxRate: number
(float)
The tax rate.
object-
unit: string
The currency's ISO 4217 three-letter code.
-
value: number
(double)
A signed floating-point number whose sign depends on the API context.
objectDiscriminator Values
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Discriminator: @type-allOf[1]
An amount, usually monetary, that modifies the price charged for an order item.
object-
applicationDuration: integer
The duration for which the alteration applies to the order item price (for example: 2 months free of charge for the recurring charge).
-
description: string
Describes the semantics of this order item price alteration.
-
name: string
The order item price alteration name.
-
price:
Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "Price":"#/components/schemas/Price" } } -
priceType: string
The price category (for example: recurring, one time, or usage).
-
priority: integer
The priority for applying this alteration among all defined alterations on the order item price.
-
productOfferingPrice:
Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "ProductOfferingPriceRef":"#/components/schemas/ProductOfferingPriceRef" } } -
recurringChargePeriod: string
Specifies the recurring charge period (for example: month or week).
-
unitOfMeasure: string
Specifies the unit of measure (for example: minutes or GB).
object-
version: string
The product offering price version.
objectDiscriminator Values
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
allOf
EntityRef
-
object
Discriminator: @type-allOf[2]
Describes the relationship between products.
object-
id: string
The related product's ID.
-
relationshipType: string
Specifies the relationship type (for example: bundledBy, bundles, tiedDiscount, or tiedProduct).
objectDiscriminator Values
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
allOf
EntityRef
object-
cycleEnd:
CycleEndRef
-
cycleEndDate: string
(date-time)
The purchased product cycle end date.
-
cycleStart:
CycleStartRef
-
cycleStartDate: string
(date-time)
The purchased product cycle start date.
-
gracePeriod:
GracePeriodRef
-
productPrice: array
productPrice
-
productRelationship: array
productRelationship
-
purchaseEnd:
PurchaseEndRef
-
purchaseEndDate: string
(date-time)
The purchased product purchase end date.
-
purchaseStart:
PurchaseStartRef
-
purchaseStartDate: string
(date-time)
The purchased product purchase start date.
-
quantity: integer
Is the quantity of service while creation of a purchase product.
-
specialRatingProfile:
specialRatingProfile
Service extended rating profile linked to the product.
-
usageEnd:
UsageEndRef
-
usageEndDate: string
(date-time)
The purchased product usage end date.
-
usageStart:
UsageStartRef
-
usageStartDate: string
(date-time)
The purchased product usage start date.
-
object
CPUDatesExtension_FVO
Contains the CPU extension dates' common properties.
-
object
CycleEndRef-allOf[1]
CycleEnd reference. A CycleEnd contains details regarding cycle end date for purchased product.
-
object
CPUDatesExtension_FVO
Contains the CPU extension dates' common properties.
-
object
CycleStartRef-allOf[1]
CycleStart reference. A CycleStart contains details regarding cycle start date for purchased product.
-
object
CPUDatesExtension_FVO
Contains the CPU extension dates' common properties.
-
object
GracePeriodRef-allOf[1]
GracePeriod reference. A GracePeriod contains details regarding grace period date for purchased product.
array-
Array of:
object Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "ProductPrice":"#/components/schemas/ProductPriceOracle" } }
array-
Array of:
object Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "ProductRelationship":"#/components/schemas/ProductRelationshipOracle" } }
-
object
CPUDatesExtension_FVO
Contains the CPU extension dates' common properties.
-
object
PurchaseEndRef-allOf[1]
PurchaseEnd reference. A PurchaseEnd contains details regarding purchase end date for purchased product.
-
object
CPUDatesExtension_FVO
Contains the CPU extension dates' common properties.
-
object
PurchaseStartRef-allOf[1]
PurchaseStart reference. A PurchaseStart contains details regarding purchase start date for purchased product.
-
object
allOf
SpecialRatingProfile
Represents a product-linked special rating profile instance for BRM service extended rating.
-
object
CPUDatesExtension_FVO
Contains the CPU extension dates' common properties.
-
object
UsageEndRef-allOf[1]
UsageEnd reference. A UsageEnd contains details regarding usage end date for purchased product.
-
object
CPUDatesExtension_FVO
Contains the CPU extension dates' common properties.
-
object
UsageStartRef-allOf[1]
UsageStart reference. A UsageStart contains details regarding usage start date for purchased product.
object-
amount(required): integer
Indicates the amount of time of a given unit.
-
unit(required): string
Allowed Values:
[ "seconds", "minutes", "hours", "days", "months", "acct_cycles", "first_usage", "absolute" ]Indicates the unit of time for the CPU extension date. Can be "seconds", "minutes", "hours", "days", "months", "acct_cycles", "first_usage" and "absolute".
objectobjectobjectobjectDiscriminator Values
-
object
allOf
Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "ProductPrice":"#/components/schemas/ProductPrice" } } -
object
Discriminator: @type-allOf[1]
A description of the price and discount awarded.
object-
priceAlteration(required): array
priceAlteration
-
priceType(required): string
Allowed Values:
[ "oneTime", "recurring" ]The price type: one-time or recurring.
array-
Array of:
object Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "PriceAlteration":"#/components/schemas/PriceAlterationOracle" } }
objectDiscriminator Values
-
object
allOf
Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "PriceAlteration":"#/components/schemas/PriceAlteration" } } -
object
Discriminator: @type-allOf[1]
Is an amount, usually of money, that modifies the price charged for an order item.
object-
priceType: string
Allowed Values:
[ "AmountOverride", "DiscountPercentageOverride", "DiscountAmountOverride" ]A category that describes the price, such as AmountOverride, DiscountPercentageOverride, or DiscountAmountOverride.
objectDiscriminator Values
-
object
allOf
Discriminator: @type
Discriminator:
{ "propertyName":"@type", "mapping":{ "ProductRelationship":"#/components/schemas/ProductRelationship" } } -
object
Discriminator: @type-allOf[1]
Used to describe the relationship between products.
object-
relationshipType(required): string
Allowed Values:
[ "bundles", "bundledBy", "tiedDiscount", "tiedProduct" ]The relationship type: bundles, bundledBy, tiedDiscount, tiedProduct.
objectobjectobject-
@type: string
Identifies the service extended rating profile type.
-
data: array
data
The rating attribute values used by rating.
-
id: string
The profile identifier.
-
label: string
The label used to identify the special rating profile in rating rules.
-
name: string
The special rating profile name.
-
referenceCount: integer
The special rating profile reference count.
-
status: string
Allowed Values:
[ "noop", "provisioning", "provisioningFailed", "active", "unprovisioning", "unprovisioningFailed", "unprovisioned", "suspending", "suspendingFailed", "suspended" ]The special rating profile provisioning status.
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
SpecialRatingProfile-allOf[1]
objectobjectobject400 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
401 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
403 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
404 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
405 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
500 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
501 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
503 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
Examples
-
Example 6: Get A Product by its productCharacteristic valueType
-
Example 7: Get A Product List That Skips the First Two Results
-
Example 11: GET purchased product by specialRatingProfile.id
-
Example 13: GET purchased product by specialRatingProfile.id: Custom
Example 1: Get Product by isBundle
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?isBundle=true'
Response Body
[
{
"isBundle": true,
"name": "Voice Over IP ",
"@type": "Product",
"product": [
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"id": "0.0.0.1+-purchased_product+174363",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+174363",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+173083",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
}
],
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+173595",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+173595",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+173083",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
},
{
"isBundle": true,
"name": "Voice Over IP ",
"@type": "Product",
"product": [
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"id": "0.0.0.1+-purchased_product+175914",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+175914",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+174634",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
}
],
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+174378",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+174378",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+174634",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
}
]Example 2: Get Product by Description
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?description=DBE_Product_DESCRIPTION'
Response Body
[
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "DBE_Product_DESCRIPTION",
"terminationDate": "2018-01-01T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+168011",
"name": "Teen Telephony C4B",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+884459",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+884459",
"status": "cancelled",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+168683",
"@type": "RealizingService"
}
],
"startDate": "2018-01-01T08:00:00.00Z",
"cycleStartDate": "2018-01-01T08:00:00.00Z",
"purchaseStartDate": "2018-01-01T08:00:00.00Z",
"usageStartDate": "2018-01-01T08:00:00.00Z",
"cycleEndDate": "2018-01-01T08:00:00.00Z",
"purchaseEndDate": "2018-01-01T08:00:00.00Z",
"usageEndDate": "2018-01-01T08:00:00.00Z"
}
]Example 3: Get Product by Start Date
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?startDate=2018-01-01T08:00:00.00Z'
Response Body
[
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2018-01-01T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+168011",
"name": "Teen Telephony C4B",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+168427",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+168427",
"status": "cancelled",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+168683",
"@type": "RealizingService"
}
],
"startDate": "2018-01-01T08:00:00.00Z",
"cycleStartDate": "2018-01-01T08:00:00.00Z",
"purchaseStartDate": "2018-01-01T08:00:00.00Z",
"usageStartDate": "2018-01-01T08:00:00.00Z",
"cycleEndDate": "2018-01-01T08:00:00.00Z",
"purchaseEndDate": "2018-01-01T08:00:00.00Z",
"usageEndDate": "2018-01-01T08:00:00.00Z"
}
]Example 4: Get a Product by its productOffering name
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/0.0.0.1+-product+168011'
Response Body
[
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2018-01-01T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+168011",
"name": "Teen Telephony C4B",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+168427",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+168427",
"status": "cancelled",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+168683",
"@type": "RealizingService"
}
],
"startDate": "2018-01-01T08:00:00.00Z",
"cycleStartDate": "2018-01-01T08:00:00.00Z",
"purchaseStartDate": "2018-01-01T08:00:00.00Z",
"usageStartDate": "2018-01-01T08:00:00.00Z",
"cycleEndDate": "2018-01-01T08:00:00.00Z",
"purchaseEndDate": "2018-01-01T08:00:00.00Z",
"usageEndDate": "2018-01-01T08:00:00.00Z"
},
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+168011",
"name": "Teen Telephony C4B",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+170347",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+170347",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+170603",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
},
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+168011",
"name": "Teen Telephony C4B",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+175689",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+175689",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+175177",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
}
]Example 5: Get A Product by its ProductCharacteristic name
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?filter=$[?@.productCharacteristic[?@.name==MSISDN]]'
Response Body
[
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2018-01-01T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+168011",
"name": "Teen Telephony C4B",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+168427",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+168427",
"status": "cancelled",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+168683",
"@type": "RealizingService"
}
],
"startDate": "2018-01-01T08:00:00.00Z",
"cycleStartDate": "2018-01-01T08:00:00.00Z",
"purchaseStartDate": "2018-01-01T08:00:00.00Z",
"usageStartDate": "2018-01-01T08:00:00.00Z",
"cycleEndDate": "2018-01-01T08:00:00.00Z",
"purchaseEndDate": "2018-01-01T08:00:00.00Z",
"usageEndDate": "2018-01-01T08:00:00.00Z"
},
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+170345",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+170345",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+170601",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
}
]Example 6: Get A Product by its productCharacteristic valueType
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?filter=$[?@.productCharacteristic[?@.valueType==string]]'
Response Body
[
{
"isBundle": true,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "IMEI-006",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+167961",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+167961",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+168937",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
}
]Example 7: Get A Product List That Skips the First Two Results
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?offset=2'
Response Body
[
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2018-01-01T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+168011",
"name": "Teen Telephony C4B",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+168427",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+168427",
"status": "cancelled",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+168683",
"@type": "RealizingService"
}
],
"startDate": "2018-01-01T08:00:00.00Z",
"cycleStartDate": "2018-01-01T08:00:00.00Z",
"purchaseStartDate": "2018-01-01T08:00:00.00Z",
"usageStartDate": "2018-01-01T08:00:00.00Z",
"cycleEndDate": "2018-01-01T08:00:00.00Z",
"purchaseEndDate": "2018-01-01T08:00:00.00Z",
"usageEndDate": "2018-01-01T08:00:00.00Z"
},
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+170345",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+170345",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+170601",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
},
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+168011",
"name": "Teen Telephony C4B",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+170347",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+170347",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+170603",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
}
]Example 8: Get A Product by its productCharacteristic Value
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?filter=$[?@.productCharacteristic[?@.value==flattened_characteristic_007]]'
Response Body
[
{
"isBundle": true,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "IMEI-006",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+167961",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+167961",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+168937",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
},
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2018-01-01T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+168011",
"name": "Teen Telephony C4B",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+168427",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+168427",
"status": "cancelled",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+169803",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+168683",
"@type": "RealizingService"
}
],
"startDate": "2018-01-01T08:00:00.00Z",
"cycleStartDate": "2018-01-01T08:00:00.00Z",
"purchaseStartDate": "2018-01-01T08:00:00.00Z",
"usageStartDate": "2018-01-01T08:00:00.00Z",
"cycleEndDate": "2018-01-01T08:00:00.00Z",
"purchaseEndDate": "2018-01-01T08:00:00.00Z",
"usageEndDate": "2018-01-01T08:00:00.00Z"
}
]Example 9: Filter a Product by its Billing Account ID
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?billingAccount.id=0.0.0.1+-account+172465'
Response Body
[
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+170345",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+170345",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+170601",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
},
{
"isBundle": true,
"name": "Voice Over IP ",
"@type": "Product",
"product": [
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"id": "0.0.0.1+-purchased_product+174363",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+174363",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+173083",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
}
],
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+173595",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+173595",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+173083",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
},
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+168011",
"name": "Teen Telephony C4B",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+175689",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+175689",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+175177",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
},
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"id": "0.0.0.1+-purchased_product+174363",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+174363",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+173083",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
}
]Example 10: Filter A Product by its Realizing Service ID
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?realizingService.id=0.0.0.1+-service-telco-gsm-telephony+170601'
Response Body
[
{
"isBundle": false,
"name": "Voice Over IP ",
"@type": "Product",
"description": "Test description",
"terminationDate": "2020-01-04T08:00:00.00Z",
"productOffering": {
"id": "0.0.0.1+-product+174600",
"name": "Teen Telephony C4B0",
"@type": "ProductOffering"
},
"productCharacteristic": [
{
"id": "",
"name": "IMEI",
"valueType": "string",
"value": "IMEI_FlatTelco",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "MSISDN",
"valueType": "string",
"value": "90121391291",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"id": "0.0.0.1+-purchased_product+170345",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+170345",
"status": "active",
"quantity": 1,
"billingAccount": {
"id": "0.0.0.1+-account+172465",
"name": "Junior Walter",
"@type": "BillingAccount"
},
"realizingService": [
{
"id": "0.0.0.1+-service-telco-gsm-telephony+170601",
"@type": "RealizingService"
}
],
"startDate": "2020-01-03T08:00:00.00Z",
"cycleStartDate": "2020-01-03T08:00:00.00Z",
"purchaseStartDate": "2020-01-03T08:00:00.00Z",
"usageStartDate": "2020-01-03T08:00:00.00Z",
"cycleEndDate": "2020-01-04T08:00:00.00Z",
"purchaseEndDate": "2020-01-04T08:00:00.00Z",
"usageEndDate": "2020-01-04T08:00:00.00Z"
}
]Example 11: GET purchased product by specialRatingProfile.id
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?specialRatingProfile.id=0.0.0.1+-profile-serv_extrating+884466'
Response Body
[
{
"productRelationship": [
{
"id": "0.0.0.1+-purchased_product+504455",
"relationshipType": "bundledBy",
"@type": "ProductRelationshipOracle"
}
],
"@type": "ProductOracle",
"terminationDate": "2020-01-02T08:00:00.00Z",
"status": "active",
"id": "0.0.0.1+-purchased_product+364887",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+364887",
"billingAccount": {
"id": "0.0.0.1+-account+734874",
"name": "Junior Walter",
"@type": "BillingAccountRef"
},
"realizingService": [
{
"id": "",
"@type": "ServiceRef"
}
],
"isBundle": false,
"name": "Voice Over IP",
"specialRatingProfile": {
"id": "0.0.0.1+-profile-serv_extrating+884466",
"data": [
{
"validFor": {
"endDateTime": "",
"startDateTime": "2031-04-02T18:23:39.00Z"
},
"name": "dummy",
"value": "0039335686849545"
},
{
"validFor": {
"endDateTime": "2031-05-01T00:00:00.00Z",
"startDateTime": "2031-04-02T18:23:39.00Z"
},
"name": "dummy",
"value": "0039335873473632"
}
],
"name": "FRIENDS_FAMILY",
"label": "Smart Calling up to 5 Numbers",
"@type": "SpecialRatingProfile",
"status": "noop",
"referenceCount": 1
},
"description": "Child product inside bundle",
"productOffering": {
"id": "",
"@type": "ProductOfferingRef"
},
"productCharacteristic": [
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceId",
"valueType": "string",
"value": "BundledChildService_046",
"@type": "StringCharacteristic"
}
],
"quantity": 1,
"startDate": "2018-01-01T08:00:00.00Z",
"cycleStartDate": "2018-01-01T08:00:00.00Z",
"purchaseStartDate": "2018-01-01T08:00:00.00Z",
"usageStartDate": "2018-01-01T08:00:00.00Z",
"cycleEndDate": "2020-01-02T08:00:00.00Z",
"purchaseEndDate": "2020-01-02T08:00:00.00Z",
"usageEndDate": "2020-01-02T08:00:00.00Z"
}
]Example 12: Filtering by specialRatingProfile.name
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?specialRatingProfile.name=FRIENDS_FAMILY'
Response Body
[
{
"productRelationship": [
{
"id": "0.0.0.1+-purchased_product+364887",
"relationshipType": "bundles",
"@type": "ProductRelationshipOracle"
}
],
"@type": "ProductOracle",
"terminationDate": "2020-01-02T08:00:00.00Z",
"status": "active",
"id": "0.0.0.1+-purchased_product+504455",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+504455",
"billingAccount": {
"id": "0.0.0.1+-account+734874",
"name": "Junior Walter",
"@type": "BillingAccountRef"
},
"realizingService": [
{
"id": "",
"@type": "ServiceRef"
}
],
"isBundle": true,
"name": "Voice Over IP",
"specialRatingProfile": {
"id": "0.0.0.1+-profile-serv_extrating+663797",
"data": [
{
"validFor": {
"endDateTime": "",
"startDateTime": "2031-04-02T18:23:39.00Z"
},
"name": "dummy",
"value": "0039335686849545"
},
{
"validFor": {
"endDateTime": "2031-05-01T00:00:00.00Z",
"startDateTime": "2031-04-02T18:23:39.00Z"
},
"name": "dummy",
"value": "0039335873473632"
}
],
"name": "FRIENDS_FAMILY",
"label": "Smart Calling up to 5 Numbers",
"@type": "SpecialRatingProfile",
"status": "noop",
"referenceCount": 1
},
"description": "Bundle product for Teen Telephony C4B",
"productOffering": {
"id": "",
"@type": "ProductOfferingRef"
},
"productCharacteristic": [
{
"id": "",
"name": "ServiceId",
"valueType": "string",
"value": "BundleService_046",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
}
],
"quantity": 1,
"startDate": "2018-01-01T08:00:00.00Z",
"cycleStartDate": "2018-01-01T08:00:00.00Z",
"purchaseStartDate": "2018-01-01T08:00:00.00Z",
"usageStartDate": "2018-01-01T08:00:00.00Z",
"cycleEndDate": "2020-01-02T08:00:00.00Z",
"purchaseEndDate": "2020-01-02T08:00:00.00Z",
"usageEndDate": "2020-01-02T08:00:00.00Z"
},
{
"productRelationship": [
{
"id": "0.0.0.1+-purchased_product+504455",
"relationshipType": "bundledBy",
"@type": "ProductRelationshipOracle"
}
],
"@type": "ProductOracle",
"terminationDate": "2020-01-02T08:00:00.00Z",
"status": "active",
"id": "0.0.0.1+-purchased_product+364887",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+364887",
"billingAccount": {
"id": "0.0.0.1+-account+734874",
"name": "Junior Walter",
"@type": "BillingAccountRef"
},
"realizingService": [
{
"id": "",
"@type": "ServiceRef"
}
],
"isBundle": false,
"name": "Voice Over IP",
"specialRatingProfile": {
"id": "0.0.0.1+-profile-serv_extrating+884466",
"data": [
{
"validFor": {
"endDateTime": "",
"startDateTime": "2031-04-02T18:23:39.00Z"
},
"name": "dummy",
"value": "0039335686849545"
},
{
"validFor": {
"endDateTime": "2031-05-01T00:00:00.00Z",
"startDateTime": "2031-04-02T18:23:39.00Z"
},
"name": "dummy",
"value": "0039335873473632"
}
],
"name": "FRIENDS_FAMILY",
"label": "Smart Calling up to 5 Numbers",
"@type": "SpecialRatingProfile",
"status": "noop",
"referenceCount": 1
},
"description": "Child product inside bundle",
"productOffering": {
"id": "",
"@type": "ProductOfferingRef"
},
"productCharacteristic": [
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceId",
"valueType": "string",
"value": "BundledChildService_046",
"@type": "StringCharacteristic"
}
],
"quantity": 1,
"startDate": "2018-01-01T08:00:00.00Z",
"cycleStartDate": "2018-01-01T08:00:00.00Z",
"purchaseStartDate": "2018-01-01T08:00:00.00Z",
"usageStartDate": "2018-01-01T08:00:00.00Z",
"cycleEndDate": "2020-01-02T08:00:00.00Z",
"purchaseEndDate": "2020-01-02T08:00:00.00Z",
"usageEndDate": "2020-01-02T08:00:00.00Z"
}
]Example 13: GET purchased product by specialRatingProfile.id: Custom
This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/product?specialRatingProfile.id=88-1ZVHQ4-044'
Response Body
If successful, the response code 200 is returned with the following response body.
[
{
"@type": "Product",
"cycleStart": {
"unit": "absolute",
"amount": 0
},
"purchaseStart": {
"unit": "absolute",
"amount": 0
},
"terminationDate": "2020-01-02T08:00:00.00Z",
"gracePeriod": {
"unit": "absolute",
"amount": 0
},
"purchaseEnd": {
"unit": "absolute",
"amount": 0
},
"status": "active",
"id": "ERA_PROD_DBE_p040",
"href": "https://localhost:9998/brm/productInventory/v5/product/ERA_PROD_DBE_p040",
"billingAccount": {
"id": "cuke4brm-rsm-customer-actno-new70",
"name": "Junior Walter",
"@type": "BillingAccountRef"
},
"realizingService": [
{
"id": "one_product_characteristic-C044f",
"@type": "ServiceRef"
}
],
"usageEnd": {
"unit": "absolute",
"amount": 0
},
"isBundle": false,
"name": "Voice Over IP",
"specialRatingProfile": {
"id": "88-1ZVHQ4-044",
"@type": "SpecialRatingProfile",
"name": "FRIENDS_FAMILY",
"label": "Smart Calling up to 5 Numbers",
"status": "noop",
"referenceCount": 1,
"data": [
{
"name": "dummy",
"value": "0449335686849545",
"validFor": {
"startDateTime": "2031-04-02T18:23:39.00Z"
}
},
{
"name": "dummy",
"value": "0449335873473632",
"validFor": {
"startDateTime": "2031-04-02T18:23:39.00Z",
"endDateTime": "2031-05-01T00:00:00.00Z"
}
},
{
"name": "dummy",
"value": "0409335686849555",
"validFor": {
"startDateTime": "2031-04-02T18:23:39.00Z",
"endDateTime": "2031-05-01T00:00:00.00Z"
}
}
]
},
"description": "Child product inside bundle",
"productOffering": {
"id": "",
"@type": "ProductOfferingRef",
"name": ""
},
"productCharacteristic": [
{
"id": "PC_BundledChild_TeenTelephony_044_1f",
"name": "ServiceType",
"valueType": "string",
"value": "/service/telco/gsm/telephony",
"@type": "StringCharacteristic"
},
{
"id": "PC_BundledChild_TeenTelephony_044_2f",
"name": "ServiceId",
"valueType": "string",
"value": "BundledChildService_044ff",
"@type": "StringCharacteristic"
}
],
"usageStart": {
"unit": "absolute",
"amount": 0
},
"cycleEnd": {
"unit": "absolute",
"amount": 0
},
"quantity": 1,
"startDate": "2018-01-01T08:00:00.00Z"
}
]
Example 14: Filtering Products by Offset Dates
Note:
Filtering by offset dates is supported for the following fields: cycleStartDate, purchaseStartDate, usageStartDate, cycleEndDate, purchaseEndDate, and usageEndDate.This example shows how to retrieve products by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http\://hostname:port/brm/productInventory/v5/purchaseStartDate=2018-01-11T08:00:00.00Z&cycleEndDate=2018-03-11T08:00:00.00Z'
Response Body
[
{
"cycleEndDate": "2018-03-11T08:00:00.00Z",
"@type": "Product",
"terminationDate": "2018-03-11T08:00:00.00Z",
"gracePeriod": {
"unit": "days",
"amount": 1
},
"id": "0.0.0.1+-purchased_product+219251",
"href": "https://host:port/brm/productInventory/v5/product/0.0.0.1+-purchased_product+219251",
"status": "active",
"purchaseStartDate": "2018-01-11T08:00:00.00Z",
"usageStartDate": "2018-01-11T08:00:00.00Z",
"cycleStartDate": "2018-01-11T08:00:00.00Z",
"billingAccount": {
"id": "0.0.0.1+-account+211178",
"name": "child-billunit ",
"@type": "BillingAccountRef"
},
"purchaseEndDate": "2018-03-11T08:00:00.00Z",
"realizingService": [
{
"id": "0.0.0.1+-service-ip+220083",
"@type": "ServiceRef"
}
],
"isBundle": true,
"name": "Voice Over IP12",
"description": "Test description",
"productOffering": {
"id": "0.0.0.1+-product+47039",
"name": "Product 1a - Internet Access",
"@type": "ProductOfferingRef"
},
"productCharacteristic": [
{
"id": "",
"name": "ServiceType",
"valueType": "string",
"value": "/service/ip",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServicePassword",
"valueType": "string",
"value": "Cgbu1234#",
"@type": "StringCharacteristic"
},
{
"id": "",
"name": "ServiceLogin",
"valueType": "string",
"value": "OotbNewServiceLoginIpCPUDates_0001",
"@type": "StringCharacteristic"
}
],
"quantity": 2,
"startDate": "2018-01-11T08:00:00.00Z",
"usageEndDate": "2018-03-11T08:00:00.00Z"
}
]